/* Copyright (c) 2013, Martina Seidl, Johannes Kepler University Linz

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE. **/

/***
 * @author Martina Seidl
 * @version 1.0
 */

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;


public class BenchmarkSetIterator {
	BufferedReader in = null;
	BufferedWriter error;
	int nrSelect; 
	
	public BenchmarkSetIterator (File f, BufferedWriter error) {
		try {
			in = new BufferedReader(new FileReader(f));
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
		this.error = error;
	}

	public int getSetSize() {
		return nrSelect;
	}
	
	private void printError(String errorString) {
		try {
			error.write(errorString+"\n");
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public String getNext() {
		String parts [];
		String nextLine = null;
		
		try {
			do {
			nextLine = in.readLine();
				if (nextLine == null) {
					in.close();
					return null;
				}			
			} while (nextLine.startsWith("#") || nextLine.trim().equals(""));
			

		} catch (IOException e) {
			e.printStackTrace();
		}
		
		parts = nextLine.trim().split("\\s+");

		if (parts.length != 4) {
			printError("Invalid item "+nextLine);
			return null;
		}
		
		try {
			nrSelect = Integer.valueOf(parts[0]);
		} catch (NumberFormatException e) {
			printError("Invalid number in item "+nextLine);
			return null;
		}
		
		return parts[1]+"/"+parts[2]+"/"+parts[3];
		
	}

}
