/* Copyright (c) 2013, Martina Seidl, Johannes Kepler University Linz

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE. **/

/***
 * @author Martina Seidl
 * @version 1.0
 */

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

/** 
 * Given a file of following structure:
 * number set subset filename
 * this tool randomly selects the given number of formulas from set/subset/filename
 *
 */


public class FormulaSelection {

	/**
	 * @param input file
	 */
	public static void main(String[] args) {
		
		BufferedWriter err = null, out = null;
		String inFileName = null, errFile = null, outFile = null;
		File inFile;
		
		if (args.length != 3) {
			System.err.println("Invalid number of arguments");
			System.err.println("Usage: infile outfile errfile");
			System.exit(1);
		}
		
		inFileName = args[0];
		outFile = args[1];
		errFile = args[2];
		
		try {
			out = new BufferedWriter(new FileWriter(outFile));
			err = new BufferedWriter(new FileWriter(errFile));
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		
		inFile = new File(inFileName);
		if(!inFile.exists()) { 
			System.err.println("Input file "+inFileName+" does not exist");
			System.exit(1);
		}
		
		BenchmarkSetIterator bsIter = new BenchmarkSetIterator(inFile, err);
		RandomBenchmarkSelector rbs = new RandomBenchmarkSelector(out,err);
		String benchmarkSet;
		int setSize;
		
		
		
		while ((benchmarkSet = bsIter.getNext()) != null) {
		
			setSize = bsIter.getSetSize();	
			rbs.select(benchmarkSet, setSize, true);
		}
		
		
		
		try {
			out.close();
			err.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		

	}

}
