/* Copyright (c) 2013, Martina Seidl, Johannes Kepler University Linz

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE. **/

/***
 * @author Martina Seidl
 * @version 1.0
 */

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;



public class RandomBenchmarkSelector {
	private BufferedWriter out;
	private BufferedWriter err;
	private BufferedReader in;
	private String setName = "";
	private String prefix;

	
	public RandomBenchmarkSelector(BufferedWriter out, BufferedWriter err) {
		this.out = out;
		this.err = err;
	}
	
	
	private void printError(String error) {
		try {
			err.write(error+"\n");
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	private void print(String msg) {
		try {
			out.write(prefix+msg+"\n");
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	private String nextLine() {
		try {
			return in.readLine();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return null;
	}
	
	private void printAll() {
		String line;
		
		while ((line = nextLine()) != null) {
			print(line);
		}
	}
	
	
	
	private void selectSome(int number) {
		List<String> instances = new ArrayList<String>();
		String line;
		Random rand = new Random();
		int sel;
		
		while ((line = nextLine()) != null) {
			instances.add(line);
		}
		
		while ((number) > 0 && (instances.size() >= 1)) {
			sel = Math.abs(rand.nextInt(instances.size()));
			if (sel != 0) sel--;
			print(instances.get(sel));
			instances.remove(sel);
			number--;
		}
		
		
		if (number > 0) {
			printError("Not enough formula instances in "+setName);
		}
		
		
	}
	
	public void select(String setName, int size, boolean showPrefix) {
		
		String [] parts;
		
		
		if (showPrefix) {
		  parts = setName.split("/");
		  prefix = parts[0]+"/"+parts[1]+"/";
		}
		
		this.setName = setName;
		if (size == 0) return;
		
		try {
			in = new BufferedReader(new FileReader(setName));
		} catch (FileNotFoundException e) {
			printError("file "+setName+" not found");
			return;
		}
		
		if (size == -1) {
			printAll();
		} else {
			selectSome(size);
		}
		
		try {
			in.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		

	}
	

}
